import logging

from .exceptions import AuthorizationError, DependencyTrackApiError

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

class Components:
    """Class dedicated to all "folders" related endpoints"""

    def list_components(self):
        """List all components accessible to the authenticated user

        API Endpoint: GET /component

        :return: a list of components
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + "/component", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Unable to get a list of components"
            raise DependencyTrackApiError(description, response)

    def get_component_dependency(self, uuid):
        """Get details of project dependency.
    
        API Endpoint: GET /dependency/project/{uuid}
    
        :param id: the ID of the project to be analysed
        :type id: int
        :return: the requested project dependency
        :rtype: dist
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/dependency/component/{uuid}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting dependency for component {uuid}"
            raise DependencyTrackApiError(description, response)




import logging
from typing_extensions import dataclass_transform

from .exceptions import AuthorizationError, DependencyTrackApiError

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

class Bom:
    """Class dedicated to all "folders" related endpoints"""

    def list_project_bom(self, uuid):
        """List all components accessible to the authenticated user

        API Endpoint: GET /bom/cyclonedx/project/{uuid}

        :return: a list of bom in project
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/bom/cyclonedx/project/{uuid}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Unable to get a list of components"
            raise DependencyTrackApiError(description, response)

    def upload_project_bom(self, uuid, file):
        """Get details of project dependency.
    
        API Endpoint: POST /bom
    
        :param id: the ID of the project to be analysed
        :type id: int
        :return: the requested project dependency
        :rtype: dist
        :raises DependencyTrackApiError: if the REST call failed
        """
        files = open(file, "rb")
        data = {"project": uuid}

        response = self.session.post(self.api + f"/bom", files={"bom": files}, data=data)

        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting dependency for component {uuid}"
            raise DependencyTrackApiError(description, response)






from gt_dependency_track import DependencyTrack
import argparse

url = 'http://dependency-track.gt.solution:8081'
api_key = "gB8eNGNE0RIloZ4zxC9SpCFOHNWQIEwC"

class Main:
  if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='CI/CD integration for Dependency Track')
    parser.add_argument('--host', help="Dependency Track Hostname", required=True)
    parser.add_argument('--api_token', help="API Key", required=True)
    parser.add_argument('--product_uuid', help="Dependency Track Product ID", required=True)
    parser.add_argument('--product_version', help="Product version", required=True)
    

    args = vars(parser.parse_args())
    host = args["host"]
    api_token = args["api_token"]
    product_uuid = args["product_uuid"]
    product_version = args["product_version"]
    dt = DependencyTrack(host, api_token)

    dt.update_project(product_uuid, product_version)


import logging

from .exceptions import AuthorizationError, DependencyTrackApiError

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)


class Licenses:
    """Class dedicated to all "licenses" related endpoints"""

    def list_licenses(self):
        """List all licenses

        API Endpoint: GET /license

        :return: a list of licenses
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + "/license", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Unable to get a list of components"
            raise DependencyTrackApiError(description, response)
            
    def list_concise_licenses(self):
        """List all concise licenses

        API Endpoint: GET /license/concise

        :return: a list of  concise licenses
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + "/license/concise", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Unable to get a list of components"
            raise DependencyTrackApiError(description, response)

    def get_license(self, licenseId):
        """Get details of license.
    
        API Endpoint: GET /license/{licenseId}
    
        :param licenseId: the SPDX ID of the license
        :type licenseId: string
        :return: the requested license
        :rtype: license dist
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/license/{licenseId}")
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting license {licenseId}"
            raise DependencyTrackApiError(description, response)




import logging

from .exceptions import AuthorizationError, DependencyTrackApiError

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)


class Projects:
    """Class dedicated to all "projects" related endpoints"""

    def list_projects(self):
        """List all projects accessible to the authenticated user

        API Endpoint: GET /project

        :return: a list of projects
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + "/project", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Unable to get a list of projects"
            raise DependencyTrackApiError(description, response)
            

    def get_project_property(self, uuid):
        """Get details of project.

        API Endpoint: GET /project/{uuid}/property

        :param uuid: the ID of the project to be analysed
        :type uuid: uuid string
        :return: the requested project property
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/project/{uuid}/property", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting property for project {uuid}"
            raise DependencyTrackApiError(description, response)

    def get_project_dependency(self, uuid):
        """Get details of project dependency.
    
        API Endpoint: GET /dependency/project/{uuid}
    
        :param uuid: the ID of the project to be analysed
        :type uuid: uuid string
        :return: the requested project
        :rtype: project dependency dict
        :raises DependencyTrackApiError: if the REST call failed
        """
        
        response = self.session.get(self.api + f"/dependency/project/{uuid}", params=self.paginated_param_payload)
        print(response.url)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting dependency for project {uuid}"
            raise DependencyTrackApiError(description, response)
            
    def get_project(self, uuid):
        """Get details of project.
    
        API Endpoint: GET /project/{uuid}/property
    
        :param uuid: the ID of the project to be analysed
        :type uuid: uuid string
        :return: the requested project property
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/project/{uuid}/", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting project {uuid}"
            raise DependencyTrackApiError(description, response)

    def update_project(self, uuid, version):
        """Update project info.
    
        API Endpoint: POST /project/{uuid}
    
        :param uuid: the ID of the project to be analysed
        :type uuid: uuid string
        :return: the requested project property
        :rtype: list()
        :raises DependencyTrackApiError: if the REST call failed
        """
        
        response = self.session.post(self.api + f"/project/{uuid}/", json={"version": version}, params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while getting project {uuid}"
            raise DependencyTrackApiError(description, response)


import logging
import requests

from .projects import Projects
from .components import Components
from .licenses import Licenses
from .bom import Bom
from .exceptions import AuthenticationError, DependencyTrackApiError

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

class DependencyTrack(Projects, Components, Licenses, Bom):

    """Main DependencyTrack API class

    Manipulation against a running DependencyTrack instance is performed using an API key.

    :Example:

    >>> from dependencytrack import DependencyTrack
    >>> dt = DependencyTrack(url, api_key)

    .. note::
        
        The class instantiation exits if the session with the DependencyTrack server
        can't be established

    :param url: URL of the DependencyTrack instance
    :param api_key: The API key generated using the DependencyTrack UI
    :type url: str
    :type api_key: str
    :raises AuthenticationError: if the api_key couldn't be found
    """

    def __init__(self, url, api_key):
        self.host = url
        self.api_key = api_key

        self.api = self.host + "/api/v1"
        self.session = requests.Session()
        self.session.headers.update({"X-Api-Key": f"{self.api_key}", "X-Total-Count": '5aa0'})
        """
        Most APIs are paginated so if you have more than 100 results you’ll need to page through them.
        X-Total-Count header seems no use to increase the number of result.
        So using parameter is my workround for now. Guess 10000 will fit for most of situation.
        """
        self.paginated_param_payload = {'pageSize': "10000", 'pageNumber': "1"}

        logger.info(
            f"DependencyTrack instance against {self.host} using {self.api}"
        )
        
    def close(self):
        self.session.close()

    def search(self, query):
        """Search from the server
    
        API endpoint: GET /search/{query}
        
        :Example:
        >>> dt.search('dnsmasq-2.78')['results']['component']
        
        :return: the seatch result
        :rtype: dict {'license': [], 'project': [], 'component': [], 'vulnerability': []}
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/search/{query}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()['results']
        else:
            description = f"Error while searching"
            raise DependencyTrackApiError(description, response)
            
    def search_component(self, query):
        """Search component from the server
    
        API endpoint: GET /component/?searchText={query}
        
        :Example:
        >>> dt.search_component('dnsmasq-2.78')
        
        :return: the seatch result
        :rtype: dict
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/component/?searchText={query}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while component searching"
            raise DependencyTrackApiError(description, response)

    def search_project(self, query):
        """Search project from the server
    
        API endpoint: GET /project/?searchText={query}
        
        :Example:
        >>> dt.search_project('my project')['results']['component']
        
        :return: the seatch result
        :rtype: dict
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/project/?searchText={query}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while project searching"
            raise DependencyTrackApiError(description, response)

    def search_vulnerability(self, query):
        """Search vulnerability from the server
    
        API endpoint: GET /vulnerability/?searchText={query}
        
        :Example:
        >>> dt.search_vulnerability('my vulnerability')
        
        :return: the seatch result
        :rtype: dict
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/vulnerability/?searchText={query}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while vulnerability searching"
            raise DependencyTrackApiError(description, response)

    def search_license(self, query):
        """Search license from the server
    
        API endpoint: GET /license/?searchText={query}
        
        :Example:
        >>> dt.search_license('my license')
        
        :return: the seatch result
        :rtype: dict
        :raises DependencyTrackApiError: if the REST call failed
        """
        response = self.session.get(self.api + f"/license/?searchText={query}", params=self.paginated_param_payload)
        if response.status_code == 200:
            return response.json()
        else:
            description = f"Error while license searching"
            raise DependencyTrackApiError(description, response)




from gt_dependency_track import DependencyTrack
url = 'http://dependency-track-api-8081'
api_key = '<<change here>>'
dt = DependencyTrack(url, api_key)

print("List of project uuid")
list_projects = dt.list_projects()
for project in list_projects:
    print(project['uuid'])

print("Upload bom")
dt.upload_project_bom('<<change here>>', 'bom.json')



class Error(Exception):
    """Base class for exceptions in this module."""

    pass


class AuthenticationError(Error):
    """Authentication error"""

    def __init__(self, url):
        self.url = url
        self.message = (
            f"An error occurred during authentication against {self.url}\n"
            f"Check your API Token and try again"
        )


class AuthorizationError(Error):
    """Authorization error"""

    def __init__(self, description, response):
        self.message = (
            f"{description}\n{response.json()['message']} ({response.status_code})"
        )


class DependencyTrackApiError(Error):
    """Error during a DependencyTrack GET request"""

    def __init__(self, description, response):
        self.message = (
            f"{description}: '{response.json()['message']}' ({response.status_code})"
        )
